(* ::Package:: *)

(* :Title: PhysicalConstantErrors 2010 CODATA *)

(* :Author: J. Gregory Moxness *)
(* modified J. Gregory Moxness 2011/07/24 *)

(* :Summary:
This package provides the relative standard error values of various commonly used physical constants.
*)

(* :Package Version: 0.2 *)

(* :Context: Miscellaneous`PhysicalConstantErrors` *)

(* :History: 
	Version 0.1 by J. Gregory Moxness, 2001. used 1998 CODATA
	Version 0.2 by J. Gregory Moxness, 2007. changed to 2006 CODATA
	Version 0.3 by J. Gregory Moxness, 2011. changed to 2010 CODATA
*)

(* :Keywords: *)

(* :Source:
	NIST CODATA, http://physics.nist.gov/cuu/Constants, 2010.
*)

(* :Warning: None. *)

(* :Mathematica Version: 4.0 *)

(* :Limitation: None. *)
(* :Discussion: *)

BeginPackage["PhysicalConstantErrors`"]

(* ================= FUNDAMENTAL CONSTANT RELATIVE STANDARD UNCERTAINTY ========================== *)

VacuumPermeabilityError = 0
VacuumPermittivityError = VacuumPermeabilityError
SpeedOfLightError=VacuumPermeabilityError

AvagadroConstantError = 0 (* N_A is defined exact which defines the Mole, 
							and gives the proposed definition for (Kilo)Gram, 
							divisible by 12 for a Mole of Carbon-12 *)

RydbergConstantError = 5.0 10^-12
ElectronMagneticMomentAnomalyError = 2.3 10^-10

FineStructureConstantError = 3.2 10^-10
InverseFineStructureConstantError = FineStructureConstantError

ElementaryChargeError = 2.2 10^-8
PlanckConstantError = 2 ElementaryChargeError

ElectronMassError = PlanckConstantError (* Relative Electron/Atomic Mass (u) Error = 4.4 10^-10 *)
ProtonElectronMassRatioError = ElectronMassError
ProtonMassError = ProtonElectronMassRatioError

NeutronMassError = ProtonMassError
MuonMassError = ProtonMassError
DeuteronMassError = ProtonMassError

ProtonMagneticMomentError = 8.2 10^-9 (* 1.02 ElementaryChargeError *)
DeuteronMagneticMomentError = ProtonMagneticMomentError
NeutronMagneticMomentError = 2.4 10^-7
MuonMagneticMomentAnomalyError = 5.4 10^-7

Pion0MassError = 9 10^-7
PionMassError = 5.0 10^-6

MolarGasConstantError = 9.1 10^-7 (* R *)
BoltzmannConstantError = MolarGasConstantError (* R/N_A  with N_A defined *)

SackurTetrodeConstantError = 2.0 10^-6
FermiConstantError = 4.3 10^-6

GravitationalConstantError = 1.2 10^-4

WeakMixingRatioError = 9.5 10^-3 (* CODATA 2010: Sin[ThetaW]^2,  MSbar @ M(Z) scheme @ 0.23122(15) *)
WeakBosonMassError = WeakMixingRatioError
ZBosonMassError = WeakBosonMassError

CosmicMicrowaveBackgroundRadiationTemperatureError = 1.1 10^-3

HiggsMassError = 8.0 10^-3

StrongCouplingConstantError = 0.01 
CabibboAngleError = 0.01 

HubbleConstantError = 0.02

VectorAxialCouplingConstantError = 0.1

Begin["`Private`"]


End[ ] (* Private` *)

EndPackage[]
